@@ -4,8 +4,8 @@
 
 ;; Author: Alvaro Ramirez https://xenodium.com
 ;; URL: https://github.com/xenodium/acp.el
-;; Package-Version: 20260221.2307
-;; Package-Revision: 49de56f0de32
+;; Package-Version: 20260302.1640
+;; Package-Revision: f7e20ce831ce
 ;; Package-Requires: ((emacs "28.1"))
 
 (defconst acp-package-version "0.11.1")
@@ -163,7 +163,16 @@ the error is logged."
                                         (run-at-time 0 nil
                                                      (lambda ()
                                                        (while message-queue
-                                                         (let ((message (car message-queue)))
+                                                         ;; Bind print variables so the debugger
+                                                         ;; can safely print the client alist
+                                                         ;; without infinite recursion (#360).
+                                                         (let ((message (car message-queue))
+                                                               ;; Handle circular refs in client alist.
+                                                               (print-circle t)
+                                                               ;; Cap nesting depth.
+                                                               (print-level 25)
+                                                               ;; Cap list elements printed.
+                                                               (print-length 200))
                                                            (setq message-queue (cdr message-queue))
                                                            (acp--route-incoming-message
                                                             :message message
